import os
import sys
current_path = os.path.dirname(os.path.realpath(__file__))
sys.path.append(os.path.join(current_path,"libs"))

import BIMM

def bimm_from_path(str,dict_path=""):
    if dict_path=="":
        dict_path=current_path+"/data/30wChinesesSeqDic_clean.txt"
    return BIMM.bimm_from_path(str,dict_path)

def fmm(str,words_dict):
    return BIMM.fmm(str,words_dict)

def bimm(str,words_dict):
    return BIMM.bimm(str,words_dict)

def bmm(str,words_dict):
    return BIMM.bmm(str,words_dict)

def read_dict(dict_path):
    return BIMM.read_dict(dict_path)


import os
import sys
current_path = os.path.dirname(os.path.realpath(__file__))
sys.path.append(os.path.join(current_path,"libs"))

import HMM

def hmm_train(input_data,prob_start_file,prob_emit_file,prob_trans_file):
    return HMM.hmm_train(input_data,prob_start_file,prob_emit_file,prob_trans_file)

def hmm_cut(prob_start_file, prob_trans_file, prob_emit_file, test_str):
    result = HMM.hmm_cut_str(prob_start_file, prob_trans_file, prob_emit_file, test_str)
    return result